@@ -1,13 +1,15 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hr">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="hr">
 <context>
     <name>AppearanceManager</name>
     <message>
         <source>Display scaling</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Log out for display scaling settings to take effect</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Set successfully</source>
@@ -23,7 +25,14 @@
     </message>
     <message>
         <source>Start setting display scaling, please wait patiently</source>
-        <translation type="unfinished"/>
+        <translation type="unfinished"></translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+<context>
+    <name>QObject</name>
+    <message>
+        <source>This system wallpaper is locked. Please contact your admin.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+</TS>
