@@ -13,6 +13,7 @@
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gtk/gtk.h>
+#include <utility>
 
 #include <X11/Xcursor/Xcursor.h>
 
@@ -270,9 +271,10 @@ QVector<QImage*> getCursors(QString dir, int size)
 
 QList<QIcon> getIcons(QString theme, int size)
 {
+    Q_UNUSED(size); // Suppress unused parameter warning
     QList<QIcon> images;
     QIcon::setThemeName(theme);
-    for(const auto &icons : qAsConst(presentIcons)) {
+    for(const auto &icons : std::as_const(presentIcons)) {
         for (auto &&iconName:icons) {
             QIcon icon(new CompatibleEngine(iconName)); // QIcon::fromTheme(iconName); DTK中DCI支持不完整，暂用CompatibleEngine处理兼容
             if (!icon.isNull()) {
@@ -366,6 +368,7 @@ QImage* loadXCursor(QString fileName, int size)
 
 QString getGlobal(QString id, QSharedPointer<Theme> theme, QString gtkTheme)
 {
+    Q_UNUSED(id); // Suppress unused parameter warning
     if (!checkScaleFactor()) {
         qInfo() << "scaleFactor <= 0";
         return "";
